bayespy.inference.vmp.nodes.gaussian.GaussianGammaISOToGaussianGammaARD.plates_multiplier
=========================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. autoattribute:: GaussianGammaISOToGaussianGammaARD.plates_multiplier